==> PopED_0.1.1.tar.gz: PopED/tests/testthat/test_distributions.R <==
context("Distributions")

test_that("pargen works", {
  
  source("examples_fcn_doc/warfarin_optimize.R")
  
  # Adding 40% Uncertainty to fixed effects log-normal (not Favail)
  bpop_vals <- c(CL=0.15, V=8, KA=1.0, Favail=1)
  bpop_vals_ed_ln <- cbind(ones(length(bpop_vals),1)*4, # log-normal distribution
                           bpop_vals,
                           ones(length(bpop_vals),1)*(bpop_vals*0.4)^2) # 40% of bpop value
  bpop_vals_ed_ln["Favail",]  <- c(0,1,0)
  
  # with log-normal distributions
  set.seed(1234,kind="Mersenne-Twister",normal.kind="Inversion")
  pars.ln <- pargen(par=bpop_vals_ed_ln,
                    user_dist_pointer=NULL,
                    sample_size=1000,
                    bLHS=1,
                    sample_number=NULL,
                    poped.db)
  
  #   #looks ok
  #   colMeans(pars.ln)
  #   var(pars.ln)
  mean.diff.ln <- (colMeans(pars.ln) - bpop_vals_ed_ln[,2])/bpop_vals_ed_ln[,2]*100
  var.diff.ln <- (diag(var(pars.ln)) - bpop_vals_ed_ln[,3])/bpop_vals_ed_ln[,3]*100
  
  expect_that(all(mean.diff.ln<20),is_true())
  expect_that(all(var.diff.ln[1:3]<50),is_true())
  
  p.vals <- apply(pars.ln[,1:3],2,function(x) shapiro.test(log(x))[["p.value"]])
  expect_that(all(p.vals > 0.8), is_true())
  
  
  
  
  # Adding 10% Uncertainty to fixed effects normal-distribution (not Favail)
  bpop_vals_ed_n <- cbind(ones(length(bpop_vals),1)*1, # log-normal distribution
                          bpop_vals,
                          ones(length(bpop_vals),1)*(bpop_vals*0.1)^2) # 10% of bpop value
  bpop_vals_ed_n["Favail",]  <- c(0,1,0)
  bpop_vals_ed_n
  
  # with normal distributions
  set.seed(1234,kind="Mersenne-Twister",normal.kind="Inversion")
  pars.n <- pargen(par=bpop_vals_ed_n,
                   user_dist_pointer=NULL,
                   sample_size=1000,
                   bLHS=1,
                   sample_number=NULL,
                   poped.db)
  
  #   # Looks ok
  #   colMeans(pars.n)
  #   var(pars.n)
  #   
  mean.diff.n <- (colMeans(pars.n) - bpop_vals_ed_n[,2])/bpop_vals_ed_n[,2]*100
  var.diff.n <- (diag(var(pars.n)) - bpop_vals_ed_n[,3])/bpop_vals_ed_n[,3]*100
  
  expect_that(all(mean.diff.n<20),is_true())
  expect_that(all(var.diff.n[1:3]<50),is_true())
  
  p.vals <- apply(pars.n[,1:3],2,function(x) shapiro.test(x)[["p.value"]])
  expect_that(all(p.vals > 0.8), is_true())
  
  
  
  # Adding 10% Uncertainty to fixed effects uniform-distribution (not Favail)
  bpop_vals_ed_u <- cbind(ones(length(bpop_vals),1)*2, # uniform distribution
                          bpop_vals,
                          ones(length(bpop_vals),1)*(bpop_vals*0.1)) # 10% of bpop value
  bpop_vals_ed_u["Favail",]  <- c(0,1,0)
  bpop_vals_ed_u
  
  # with normal distributions
  set.seed(1234,kind="Mersenne-Twister",normal.kind="Inversion")
  pars.u <- pargen(par=bpop_vals_ed_u,
                   user_dist_pointer=NULL,
                   sample_size=100,
                   bLHS=1,
                   sample_number=NULL,
                   poped.db)
  
  mean.diff.u <- (colMeans(pars.u) - bpop_vals_ed_u[,2])/bpop_vals_ed_u[,2]*100
  range.diff.u <- mean.diff.u
  for(i in 1:4){
    range.diff.u[i] <- (diff(range(pars.u[,i])) - bpop_vals_ed_u[i,3])/bpop_vals_ed_u[i,3]*100
  }
  
  expect_that(all(mean.diff.u<20),is_true())
  expect_that(all(range.diff.u[1:3]<50),is_true())
  
})

test_that("log_prior_pdf works", {
  
  source("examples_fcn_doc/warfarin_optimize.R")
  source("examples_fcn_doc/examples_log_prior_pdf.R")
  
  # then compute the log density from log_prior_pdf
  alpha <- bpop_vals_ed_n[bpop_vals_ed_n[,1]!=0,2]
  lp.1 <- log_prior_pdf(alpha=alpha, bpopdescr=bpop_vals_ed_n, ddescr=poped.db$gd)
  
  # compute the log density from dnorm
  par <- bpop_vals_ed_n[bpop_vals_ed_n[,1]==1,]
  lp.2 <- log(prod(dnorm(par[,2],par[,2],sqrt(par[,3]))))
  
  test_that(lp.1,equals(lp.2))
  
  # then compute the log density 
  alpha <- bpop_vals_ed_ln[bpop_vals_ed_ln[,1]!=0,2]
  lp.3 <- log_prior_pdf(alpha=alpha, bpopdescr=bpop_vals_ed_ln, ddescr=poped.db$gd)
  
  # compute the log density from dlnorm
  par <- bpop_vals_ed_ln[bpop_vals_ed_ln[,1]==4,]
  lp.4 <- log(prod(dlnorm(par[,2],log(par[,2]^2/sqrt(par[,3]+par[,2]^2)),sqrt(log(par[,3]/par[,2]^2+1)))))
  
  test_that(lp.3,equals(lp.4))
  
  # then compute the log density 
  alpha <- bpop_vals_ed_ln[bpop_vals_ed_u[,1]!=0,2]
  lp.5 <- log_prior_pdf(alpha=alpha, bpopdescr=bpop_vals_ed_u, ddescr=poped.db$gd)
  
  # compute the log density from dlnorm
  par <- bpop_vals_ed_u[bpop_vals_ed_u[,1]==2,]
  lp.6 <- log(prod(dunif(par[,2],min=par[,2]-par[,3]/2,max=par[,2]+par[,3]/2)))
  
  test_that(lp.5,equals(lp.6))
  
  
})

==> PopED_0.2.0.tar.gz: PopED/tests/testthat/test_distributions.R <==
context("Distributions")

test_that("pargen works", {
  
  source("examples_fcn_doc/warfarin_optimize.R")
  
  # Adding 40% Uncertainty to fixed effects log-normal (not Favail)
  bpop_vals <- c(CL=0.15, V=8, KA=1.0, Favail=1)
  bpop_vals_ed_ln <- cbind(ones(length(bpop_vals),1)*4, # log-normal distribution
                           bpop_vals,
                           ones(length(bpop_vals),1)*(bpop_vals*0.4)^2) # 40% of bpop value
  bpop_vals_ed_ln["Favail",]  <- c(0,1,0)
  
  # with log-normal distributions
  set.seed(1234,kind="Mersenne-Twister",normal.kind="Inversion")
  pars.ln <- pargen(par=bpop_vals_ed_ln,
                    user_dist_pointer=NULL,
                    sample_size=1000,
                    bLHS=1,
                    sample_number=NULL,
                    poped.db)
  
  #   #looks ok
  #   colMeans(pars.ln)
  #   var(pars.ln)
  mean.diff.ln <- (colMeans(pars.ln) - bpop_vals_ed_ln[,2])/bpop_vals_ed_ln[,2]*100
  var.diff.ln <- (diag(var(pars.ln)) - bpop_vals_ed_ln[,3])/bpop_vals_ed_ln[,3]*100
  
  expect_that(all(mean.diff.ln<20),is_true())
  expect_that(all(var.diff.ln[1:3]<50),is_true())
  
  p.vals <- apply(pars.ln[,1:3],2,function(x) shapiro.test(log(x))[["p.value"]])
  expect_that(all(p.vals > 0.8), is_true())
  
  
  
  
  # Adding 10% Uncertainty to fixed effects normal-distribution (not Favail)
  bpop_vals_ed_n <- cbind(ones(length(bpop_vals),1)*1, # log-normal distribution
                          bpop_vals,
                          ones(length(bpop_vals),1)*(bpop_vals*0.1)^2) # 10% of bpop value
  bpop_vals_ed_n["Favail",]  <- c(0,1,0)
  bpop_vals_ed_n
  
  # with normal distributions
  set.seed(1234,kind="Mersenne-Twister",normal.kind="Inversion")
  pars.n <- pargen(par=bpop_vals_ed_n,
                   user_dist_pointer=NULL,
                   sample_size=1000,
                   bLHS=1,
                   sample_number=NULL,
                   poped.db)
  
  #   # Looks ok
  #   colMeans(pars.n)
  #   var(pars.n)
  #   
  mean.diff.n <- (colMeans(pars.n) - bpop_vals_ed_n[,2])/bpop_vals_ed_n[,2]*100
  var.diff.n <- (diag(var(pars.n)) - bpop_vals_ed_n[,3])/bpop_vals_ed_n[,3]*100
  
  expect_that(all(mean.diff.n<20),is_true())
  expect_that(all(var.diff.n[1:3]<50),is_true())
  
  p.vals <- apply(pars.n[,1:3],2,function(x) shapiro.test(x)[["p.value"]])
  expect_that(all(p.vals > 0.8), is_true())
  
  
  
  # Adding 10% Uncertainty to fixed effects uniform-distribution (not Favail)
  bpop_vals_ed_u <- cbind(ones(length(bpop_vals),1)*2, # uniform distribution
                          bpop_vals,
                          ones(length(bpop_vals),1)*(bpop_vals*0.1)) # 10% of bpop value
  bpop_vals_ed_u["Favail",]  <- c(0,1,0)
  bpop_vals_ed_u
  
  # with normal distributions
  set.seed(1234,kind="Mersenne-Twister",normal.kind="Inversion")
  pars.u <- pargen(par=bpop_vals_ed_u,
                   user_dist_pointer=NULL,
                   sample_size=100,
                   bLHS=1,
                   sample_number=NULL,
                   poped.db)
  
  mean.diff.u <- (colMeans(pars.u) - bpop_vals_ed_u[,2])/bpop_vals_ed_u[,2]*100
  range.diff.u <- mean.diff.u
  for(i in 1:4){
    range.diff.u[i] <- (diff(range(pars.u[,i])) - bpop_vals_ed_u[i,3])/bpop_vals_ed_u[i,3]*100
  }
  
  expect_that(all(mean.diff.u<20),is_true())
  expect_that(all(range.diff.u[1:3]<50),is_true())
  
})

test_that("log_prior_pdf works", {
  
  source("examples_fcn_doc/warfarin_optimize.R")
  source("examples_fcn_doc/examples_log_prior_pdf.R")
  
  # then compute the log density from log_prior_pdf
  alpha <- bpop_vals_ed_n[bpop_vals_ed_n[,1]!=0,2]
  lp.1 <- log_prior_pdf(alpha=alpha, bpopdescr=bpop_vals_ed_n, ddescr=poped.db$parameters$d)
  
  # compute the log density from dnorm
  par <- bpop_vals_ed_n[bpop_vals_ed_n[,1]==1,]
  lp.2 <- log(prod(dnorm(par[,2],par[,2],sqrt(par[,3]))))
  
  test_that(lp.1,equals(lp.2))
  
  # then compute the log density 
  alpha <- bpop_vals_ed_ln[bpop_vals_ed_ln[,1]!=0,2]
  lp.3 <- log_prior_pdf(alpha=alpha, bpopdescr=bpop_vals_ed_ln, ddescr=poped.db$parameters$d)
  
  # compute the log density from dlnorm
  par <- bpop_vals_ed_ln[bpop_vals_ed_ln[,1]==4,]
  lp.4 <- log(prod(dlnorm(par[,2],log(par[,2]^2/sqrt(par[,3]+par[,2]^2)),sqrt(log(par[,3]/par[,2]^2+1)))))
  
  test_that(lp.3,equals(lp.4))
  
  # then compute the log density 
  alpha <- bpop_vals_ed_ln[bpop_vals_ed_u[,1]!=0,2]
  lp.5 <- log_prior_pdf(alpha=alpha, bpopdescr=bpop_vals_ed_u, ddescr=poped.db$parameters$d)
  
  # compute the log density from dlnorm
  par <- bpop_vals_ed_u[bpop_vals_ed_u[,1]==2,]
  lp.6 <- log(prod(dunif(par[,2],min=par[,2]-par[,3]/2,max=par[,2]+par[,3]/2)))
  
  test_that(lp.5,equals(lp.6))
  
  
})
